# DBTonFHIR

## Description

The goal is to be able to map from a given source to a FHIR server without the help of a gui leveraging existing tools
such as git and DBT.

## Documentation

Read the [docs](https://arkhn.github.io/dbtonfhir/) !
